# WIFI Bridge Documentation

## ESP8266 ESP-01 Programming

This document will go over all the steps needed to program the ESP8266 ESP-01 chip
used on the MicroCART quad. These chips are a SOC (System on chip) design meaning that they can
be programmed as they act like a small computer. The base directory for the AP software is in the 
folder [ESP8266_Wifi-Serial-Adapter-AP](./ESP8266_Wifi-Serial-Adapter-AP). The base directory for the 
Client software is in the folder [ESP8266_Wifi_Serial_Adapter-Client](./ESP8266_Wifi_Serial_Adapter_Client).

### Hardware Setup

The ESP-01 chip contains on-board memory which can be flashed with a program
that the chip is intended to run. There are multiple setups that can be used
to program the chip, like using an [Arduino](./images/ESP8266_setup.png), but the approach that is taken is
using a circuit with buttons to control reset and GPIO 2, with a USB converter.
This circuit was taken from [here](https://www.allaboutcircuits.com/projects/breadboard-and-program-an-esp-01-circuit-with-the-arduino-ide/).

A perfboard design has been made, as seen below, and can be found in the MicroCART cabinet in the corner of the lab. The pinout should be included on the box that
contains the board, but will also be shown below. Note that the USB convert chip can also
be swapped if needed. Also if you would like to design your own circuit please seen the actual
circuit also included below.

![alt text](./images/perfboard_circuit.png "Perfboard Circuit")

Pinouts:

![alt text](./images/perfboard_pinout.png "Perfboard Pinout")

Below is an image of the circuit:

![alt text](./images/ESP-01_Connection_Diagram.png "ESP Programming Circuit")

### Software setup

The current software that runs on the chip does not use the Arduino IDE for
programming as it did not give the low level access needed to a reliable system, 
as it caused issues with dropping packets (but this could be a fun process of porting 
the software to work correctly within the Arduino IDE for ease of use). As such
esp-open-sdk is needed. This is open source software than can be installed from 
[here](https://github.com/pfalcon/esp-open-sdk), the repository also goes over
the installation process. Please note that this process may take about 40 minutes. Also,
note that this is not installed on the MicroCART computers in the lab.
You will need the following packages installed:

    gperf bison flex texinfo help2man gawk make libtool-bin libncurses5-dev

Once esp-open-sdk is installed open the [Makefile](./ESP8266_Wifi-Serial-Adapter-AP/Makefile) within [ESP8266_Wifi-Serial-Adapter-AP](./ESP8266_Wifi-Serial-Adapter-AP)
directory. This Makefile needs the path to the compiler named [XTENSA_TOOLS_ROOT](./ESP8266_Wifi-Serial-Adapter-AP/Makefile#L22),
the base directory of the ESP8266 SDK package named [SDK_BASE](./ESP8266_Wifi-Serial-Adapter-AP/Makefile#L26) and
as well as the port the ESP programming circuit is connected to named [ESPPORT](./ESP8266_Wifi-Serial-Adapter-AP/Makefile#L30).

**NOTE: do the same steps as above for the Client code as well.**

### Programming Steps

After completing the software setup you should be able to run `make`. This Makefile also 
contains the capability to flash the chip with the command `make flash`. But before this
you must do the following with the hardware circuit:

  1. Hold down the RESET button.
  2. Hold down the FLASH button.
  3. Release the RESET button.
  4. Release the FLASH button.
  
The timing on these steps can be finicky but usually releasing the FLASH button a couple
seconds after the RESET button works. Now run `make flash`.

Congrats you are done programming!!

If any more explanation is needed please read the orginal page that goes over programming
with this circuit, linked above as well as [here](https://www.allaboutcircuits.com/projects/breadboard-and-program-an-esp-01-circuit-with-the-arduino-ide/).
